import { Slash } from "lucide-react";

import {
	Breadcrumb,
	BreadcrumbItem,
	BreadcrumbLink,
} from "@/components/ui/breadcrumb";
import { Link, Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";

export interface BreadcrumbItem {
	href: string;
	label: Record<Locale, string>;
}

interface CustomBreadcrumbProps {
	items: BreadcrumbItem[];
	locale: Locale;
	className?: string;
}

export function CustomBreadcrumb({
	items,
	locale,
	className,
}: CustomBreadcrumbProps) {
	const isRTL = locale === "ar";

	return (
		<Breadcrumb className={cn("text-sm", className)}>
			{items?.map((item, index) => (
				<BreadcrumbItem key={item.href}>
					<BreadcrumbLink asChild>
						<Link
							href={item.href as any}
							className={cn(
								"text-custom-background-light transition-colors hover:text-custom-primary-accent",
								index === items.length - 1 &&
								"pointer-events-none text-custom-primary-accent"
							)}
						>
							{item.label?.[locale]}
						</Link>
					</BreadcrumbLink>
					{index < items.length - 1 && (
						<Slash
							className={cn(
								"mx-1 h-4 text-custom-background-light",
								isRTL && "rotate-180"
							)}
						/>
					)}
				</BreadcrumbItem>
			))}
		</Breadcrumb>
	);
}
